Module action

Module action 

Macros

action_descriptor_map

Structs

ActionDescriptor
ActionKind
NoOk
NoParams
RequestedAction
A request from an interceptor for the orchestrator to consider executing.
RequestedActionRecord
ResolvedAction
The orchestrator’s recorded outcome for a previously requested action. If the interceptor is reinvoked, this is fed back into subsequent interceptor invocations.
ResolvedActionRecord

Traits

ActionSpec