pub struct ResolvedAction<A: ActionSpec> {
pub params: A::Params,
pub result: Result<A::Result, ProtocolError>,
}Expand description
The orchestrator’s recorded outcome for a previously requested action. If the interceptor is reinvoked, this is fed back into subsequent interceptor invocations.
Fields
params: A::Paramsresult: Result<A::Result, ProtocolError>Trait Implementations
Sourceimpl<A: Clone + ActionSpec> Clone for ResolvedAction<A>
impl<A: Clone + ActionSpec> Clone for ResolvedAction<A>
Sourcefn clone(&self) -> ResolvedAction<A>
fn clone(&self) -> ResolvedAction<A>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<A: Debug + ActionSpec> Debug for ResolvedAction<A>
impl<A: Debug + ActionSpec> Debug for ResolvedAction<A>
Sourceimpl<A: PartialEq + ActionSpec> PartialEq for ResolvedAction<A>
impl<A: PartialEq + ActionSpec> PartialEq for ResolvedAction<A>
Sourcefn eq(&self, other: &ResolvedAction<A>) -> bool
fn eq(&self, other: &ResolvedAction<A>) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl<A> TryFrom<ResolvedAction<A>> for ResolvedActionRecord
impl<A> TryFrom<ResolvedAction<A>> for ResolvedActionRecord
Sourceimpl<A> TryFrom<ResolvedActionRecord> for ResolvedAction<A>where
A: ActionSpec,
impl<A> TryFrom<ResolvedActionRecord> for ResolvedAction<A>where
A: ActionSpec,
Sourcetype Error = ActionCodecError
type Error = ActionCodecError
The type returned in the event of a conversion error.
impl<A: ActionSpec> StructuralPartialEq for ResolvedAction<A>