#[non_exhaustive]pub enum ActionCodecError {
KindMismatch {
expected: ActionKind,
actual: ActionKind,
},
InvalidParams {
action: ActionKind,
source: Error,
},
InvalidResult {
action: ActionKind,
source: Error,
},
MissingParams {
action: ActionKind,
},
MissingOkResult {
action: ActionKind,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
KindMismatch
thrown when requested/resolved action andn requested/resolved action record types does not match
InvalidParams
thrown when requested action record params doesnt match with the requested action type
InvalidResult
thrown when resolved action record result cannot be decoded to resolved action result
MissingParams
thrown when requested action record does not have params but requested action does
Fields

action: ActionKindMissingOkResult
thrown when resolved action record does not have params but resolved action does
Fields

action: ActionKindTrait Implementations
Sourceimpl Debug for ActionCodecError
impl Debug for ActionCodecError
Sourceimpl Display for ActionCodecError
impl Display for ActionCodecError
Sourceimpl Error for ActionCodecError
impl Error for ActionCodecError
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<ActionCodecError> for Error
impl From<ActionCodecError> for Error
Sourcefn from(source: ActionCodecError) -> Self
fn from(source: ActionCodecError) -> Self
Converts to this type from the input type.